@@ -78,63 +78,63 @@ def send_sms():
     headers = request.headers or {}
     json_doc = request.get_json() or {}
     msisdn = json_doc["msisdn"]
-    if (msisdn[-9:]).startswith("34") or (msisdn[-9:]).startswith("39"):
-        pass
+    # if (msisdn[-9:]).startswith("34") or (msisdn[-9:]).startswith("39"):
+    #     pass
+    # else:
+    if user.startswith('partenaire'):
+        sender_id = user.split('_')[1]
     else:
-        if user.startswith('partenaire'):
-            sender_id = user.split('_')[1]
-        else:
-            sender_id = json_doc.get('sender_id', 'bip')
-        try:
-            logging.warn(sender_id)
-            json_doc['sender_id'] = sender_id
-            queue = CONFIG[sender_id]['account']
-        except KeyError:
-            return bad_request(
-                message="Le sender_id n'exist pas",
-                code='{}-{}'.format(
-                    SERVICE_CODE,
-                    '4001'
-                    ),
-                service_code=SERVICE_CODE
+        sender_id = json_doc.get('sender_id', 'bip')
+    try:
+        logging.warn(sender_id)
+        json_doc['sender_id'] = sender_id
+        queue = CONFIG[sender_id]['account']
+    except KeyError:
+        return bad_request(
+            message="Le sender_id n'exist pas",
+            code='{}-{}'.format(
+                SERVICE_CODE,
+                '4001'
+                ),
+            service_code=SERVICE_CODE
+            )
+        # queue = CONFIG['bip']['account']
+    document = {
+        'auth': auth or (),
+        'params': params,
+        'headers': headers,
+        'json': json_doc
+        }
+    try:
+        connection = pika.BlockingConnection(
+            pika.ConnectionParameters(
+                host='localhost',
+                virtual_host='/smsc'
                 )
-            # queue = CONFIG['bip']['account']
-        document = {
-            'auth': auth or (),
-            'params': params,
-            'headers': headers,
-            'json': json_doc
-            }
-        try:
-            connection = pika.BlockingConnection(
-                pika.ConnectionParameters(
-                    host='localhost',
-                    virtual_host='/smsc'
-                    )
-                )
-        except Exception:
-            # exception de connection lancée par pika
-            # il faut que rabbitmq-server soit installé
-            # et que le vhost /{service} existe déjà
-            return internal_error(
-                message="serveur RabbitMQ injoignable",
-                code='{}-5000'.format(SERVICE_CODE),
-                service_code=SERVICE_CODE
-                )
-        else:
-            channel = connection.channel()
-            channel.exchange_declare(
-                exchange='sendsms',
-                exchange_type='topic'
-                )
-            # déclaration idempotente: pas grave si l'exchange existe déjà
-            channel.basic_publish(
-                exchange='sendsms',
-                routing_key=queue,
-                body=json.dumps(document),
-                properties=pika.BasicProperties(delivery_mode=2)
-                )
-            connection.close()
+            )
+    except Exception:
+        # exception de connection lancée par pika
+        # il faut que rabbitmq-server soit installé
+        # et que le vhost /{service} existe déjà
+        return internal_error(
+            message="serveur RabbitMQ injoignable",
+            code='{}-5000'.format(SERVICE_CODE),
+            service_code=SERVICE_CODE
+            )
+    else:
+        channel = connection.channel()
+        channel.exchange_declare(
+            exchange='sendsms',
+            exchange_type='topic'
+            )
+        # déclaration idempotente: pas grave si l'exchange existe déjà
+        channel.basic_publish(
+            exchange='sendsms',
+            routing_key=queue,
+            body=json.dumps(document),
+            properties=pika.BasicProperties(delivery_mode=2)
+            )
+        connection.close()
     return success(service_code=SERVICE_CODE)
 
 
